from pathlib import Path
from typing import Union, List, TypeAlias

__version__: str

PathOrStr: TypeAlias = Union[Path, str]

def tenhou_to_mjai(
    filename: PathOrStr, *, mjai_out: Union[PathOrStr, None] = None
) -> List[str]: ...

class TenhouLogParsingError(ValueError): ...
class TenhouToMjaiError(ValueError): ...
class JsonSerializationError(ValueError): ...
class JsonParsingError(ValueError): ...



from . import _convlog

__all__ = (
    "__version__",
    "TenhouLogParsingError",
    "TenhouToMjaiError",
    "JsonSerializationError",
    "JsonParsingError",
    "tenhou_to_mjai",
)

# VERSION is set in Cargo.toml
VERSION = _convlog.__version__
__version__ = _convlog.__version__
TenhouLogParsingError = _convlog.TenhouLogParsingError
TenhouToMjaiError = _convlog.TenhouToMjaiError
JsonSerializationError = _convlog.JsonSerializationError
JsonParsingError = _convlog.JsonParsingError

tenhou_to_mjai = _convlog.tenhou_to_mjai
